package
Version:
v1.7.0
Opens a new window with list of versions in this module.
Published: Jan 14, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 20
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DevUser struct {
Name string `yaml:"name"`
Email string `yaml:"email"`
Apikey string `yaml:"apikey"`
}
type DevUsersConfig struct {
Users []DevUser `yaml:"users"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.